WkbDecoder class

Decodes GeoPackage WKB (GPKG-WKB) geometries into flat Float32List coordinates.

GeoPackage stores geometries in GeoPackage Binary Format which wraps ISO WKB with a header containing magic bytes, flags, SRS ID, and optional envelope. This class strips the GPKG header and parses the ISO WKB payload.

Constructors

WkbDecoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Uint8List gpkgWkb) Float32List?
Decode a GPKG-WKB blob into flat x1,y1, x2,y2, ... coordinates.
decodeAsRecord(Uint8List gpkgWkb) Record?
Decode any geometry type and return the appropriate Record subclass
decodePoint(Uint8List gpkgWkb) Point?
Decode a GPKG-WKB blob as a Point geometry
decodePolygon(Uint8List gpkgWkb) Polygon?
Decode a GPKG-WKB blob as a Polygon geometry
decodePolyline(Uint8List gpkgWkb) Polyline?
Decode a GPKG-WKB blob as a Polyline geometry
extractEnvelope(Uint8List gpkgWkb) → ({double maxX, double maxY, double minX, double minY})?
Extract the GPKG envelope from a GPKG-WKB blob.
upgradeEnvelope(Uint8List gpkgWkb) Uint8List?
Rewrite a GPKG-WKB blob to embed an XY envelope in the header.