MultiPointZ class
MultiPointZ has required Z values and optional M values per ESRI spec
- Inheritance
-
- Object
- Record
- MultiPoint
- MultiPointZ
Constructors
Properties
-
arrayM
→ List<
double> ? -
final
-
arrayZ
→ List<
double> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasM → bool
-
Whether M values are present
no setter
- maxM → double?
-
final
- maxX → double
-
finalinherited
- maxY → double
-
finalinherited
- maxZ → double
-
final
- minM → double?
-
final
- minX → double
-
finalinherited
- minY → double
-
finalinherited
- minZ → double
-
final
- numPoints → int
-
no setterinherited
-
points
→ List<
Point> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ShapeType
-
The geometry type of this record
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toList(
) → List< Object> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited