UnsupportedTypeException class
Exception thrown when geometry type is not supported
- Inheritance
-
- Object
- ShapefileException
- UnsupportedTypeException
Constructors
- UnsupportedTypeException(String geometryType, {String? filePath})
-
Creates an unsupported type exception
const
Properties
- details → String?
-
Additional details about the error
finalinherited
- filePath → String?
-
Path to the file that caused the error (if applicable)
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error message describing what went wrong
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ShapefileErrorType
-
Type of error that occurred
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited